"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LiquidDocTagHoverProvider = void 0;
const liquid_html_parser_1 = require("@shopify/liquid-html-parser");
const vscode_languageserver_1 = require("vscode-languageserver");
const liquidDoc_1 = require("../../utils/liquidDoc");
class LiquidDocTagHoverProvider {
    constructor() { }
    async hover(currentNode, ancestors) {
        const parentNode = ancestors.at(-1);
        let docTagNode;
        // We could be hovering on the liquidDoc tag itself
        if (currentNode.type === liquid_html_parser_1.NodeTypes.LiquidDocParamNode ||
            currentNode.type === liquid_html_parser_1.NodeTypes.LiquidDocDescriptionNode ||
            currentNode.type === liquid_html_parser_1.NodeTypes.LiquidDocExampleNode) {
            docTagNode = currentNode;
        }
        // or we could be hovering on the liquidDoc tag's text
        if (((parentNode === null || parentNode === void 0 ? void 0 : parentNode.type) === liquid_html_parser_1.NodeTypes.LiquidDocParamNode ||
            (parentNode === null || parentNode === void 0 ? void 0 : parentNode.type) === liquid_html_parser_1.NodeTypes.LiquidDocDescriptionNode ||
            (parentNode === null || parentNode === void 0 ? void 0 : parentNode.type) === liquid_html_parser_1.NodeTypes.LiquidDocExampleNode) &&
            currentNode.type === liquid_html_parser_1.NodeTypes.TextNode) {
            docTagNode = parentNode;
        }
        if (!docTagNode) {
            return null;
        }
        const docTagData = liquidDoc_1.SUPPORTED_LIQUID_DOC_TAG_HANDLES[docTagNode.name];
        if (!docTagData) {
            return null;
        }
        return {
            contents: {
                kind: vscode_languageserver_1.MarkupKind.Markdown,
                value: (0, liquidDoc_1.formatLiquidDocTagHandle)(docTagNode.name, docTagData.description, docTagData.example),
            },
        };
    }
}
exports.LiquidDocTagHoverProvider = LiquidDocTagHoverProvider;
//# sourceMappingURL=LiquidDocTagHoverProvider.js.map