"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RenderSnippetHoverProvider = void 0;
const liquid_html_parser_1 = require("@shopify/liquid-html-parser");
const liquidDoc_1 = require("../../utils/liquidDoc");
class RenderSnippetHoverProvider {
    constructor(getSnippetDefinitionForURI) {
        this.getSnippetDefinitionForURI = getSnippetDefinitionForURI;
    }
    async hover(currentNode, ancestors, params) {
        var _a, _b, _c;
        const parentNode = ancestors.at(-1);
        if (currentNode.type !== liquid_html_parser_1.NodeTypes.String ||
            !parentNode ||
            parentNode.type !== liquid_html_parser_1.NodeTypes.RenderMarkup) {
            return null;
        }
        const snippetName = currentNode.value;
        const snippetDefinition = await this.getSnippetDefinitionForURI(params.textDocument.uri, snippetName);
        if (!snippetDefinition) {
            return null;
        }
        const liquidDoc = snippetDefinition.liquidDoc;
        if (!liquidDoc) {
            return {
                contents: {
                    kind: 'markdown',
                    value: `### ${snippetDefinition.name}`,
                },
            };
        }
        const parts = [`### ${snippetDefinition.name}`];
        if ((_a = liquidDoc.parameters) === null || _a === void 0 ? void 0 : _a.length) {
            const parameters = this.buildParameters(liquidDoc.parameters);
            parts.push('', '**Parameters:**', parameters);
        }
        if ((_b = liquidDoc.examples) === null || _b === void 0 ? void 0 : _b.length) {
            const examples = (_c = liquidDoc.examples) === null || _c === void 0 ? void 0 : _c.map(({ content }) => `\`\`\`liquid${content}\`\`\``).join('\n');
            parts.push('', '**Examples:**', examples);
        }
        return {
            contents: {
                kind: 'markdown',
                value: parts.join('\n'),
            },
        };
    }
    buildParameters(parameters) {
        return parameters.map((param) => (0, liquidDoc_1.formatLiquidDocParameter)(param)).join('\n');
    }
}
exports.RenderSnippetHoverProvider = RenderSnippetHoverProvider;
//# sourceMappingURL=RenderSnippetHoverProvider.js.map